==> nextcloud-21.0.2.tgz: nextcloud/apps/workflowengine/l10n/ja.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定された演算子は無効",
    "The given regular expression is invalid" : "指定の正規表現は無効",
    "The given file size is invalid" : "指定されたファイルサイズは無効",
    "The given tag id is invalid" : "指定されたIDタグは無効",
    "The given IP range is invalid" : "指定されたIP範囲は無効",
    "The given IP range is not valid for IPv4" : "指定されたIPはIPv4の範囲ではありません",
    "The given IP range is not valid for IPv6" : "指定されたIPはIPv6の範囲ではありません",
    "The given time span is invalid" : "指定された期間は無効です",
    "The given start time is invalid" : "指定された開始時刻は無効です",
    "The given end time is invalid" : "指定された終了時刻は無効です",
    "The given group does not exist" : "指定されたグループは存在しません",
    "File" : "ファイル",
    "File created" : "ファイル作成時",
    "File updated" : "ファイル更新時",
    "File renamed" : "ファイル名変更時",
    "File deleted" : "ファイル削除時",
    "File accessed" : "ファイルアクセス時",
    "File copied" : "ファイル複製時",
    "Tag assigned" : "タグ割り当て時",
    "Someone" : "誰か",
    "%s created %s" : "%s が %s を作成",
    "%s modified %s" : "%s が %s を更新",
    "%s deleted %s" : "%s が %s を削除",
    "%s accessed %s" : "%s が %s にアクセス",
    "%s renamed %s" : "%s が %s をリネーム",
    "%s copied %s" : "%s を %s に複製",
    "%s assigned %s to %s" : "%s が %s を %s に割り当て",
    "Operation #%s does not exist" : "#%s 操作は存在しません",
    "Entity %s does not exist" : "エンティティー %s がありません",
    "Entity %s is invalid" : "エンティティー %s が間違っています",
    "No events are chosen." : "イベントが選択されていません。",
    "Entity %s has no event %s" : "エンティティー %s には %s のイベントはありません",
    "Operation %s does not exist" : "%s 操作は存在しません",
    "Operation %s is invalid" : "%s 操作は無効です",
    "At least one check needs to be provided" : "少なくともチェックを一つ設定してください",
    "The provided operation data is too long" : "提供された操作データが長すぎます",
    "Invalid check provided" : "チェック設定が正しくありません",
    "Check %s does not exist" : "チェック %s は存在しません",
    "Check %s is invalid" : "チェック %s は無効です",
    "Check %s is not allowed with this entity" : " チェック%s はこのエンティティーでは利用できません",
    "The provided check value is too long" : "提供されたチェック値が長すぎます",
    "Check #%s does not exist" : "チェック #%s は存在しません",
    "Check %s is invalid or does not exist" : "%sのチェックは無効か存在しません",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Nextcloud ワークフローエンジン",
    "Select a filter" : "フィルターを選択",
    "Select a comparator" : "比較演算子を指定",
    "Select a file type" : "ファイルタイプを指定",
    "e.g. httpd/unix-directory" : "例: httpd/unix-directory",
    "Folder" : "フォルダー",
    "Images" : "画像",
    "Office documents" : "Officeドキュメント",
    "PDF documents" : "PDFドキュメント",
    "Custom mimetype" : "カスタムMIMEタイプ",
    "Select a tag" : "タグを選択",
    "No results" : "該当なし",
    "%s (invisible)" : "%s (不可視)",
    "%s (restricted)" : "%s (制限)",
    "Please enter a valid time span" : "正しい間隔を指定してください",
    "Select a request URL" : "リクエストURLを選択",
    "Predefined URLs" : "定義済みのURL",
    "Files WebDAV" : "ファイルWebDAV",
    "Others" : "その他",
    "Custom URL" : "カスタムURL",
    "Select a user agent" : "ユーザーエージェントを選択",
    "Android client" : "アンドロイドクライアント",
    "iOS client" : "iOSクライアント",
    "Desktop client" : "デスクトップクライアント",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook アドオン",
    "Custom user agent" : "カスタムユーザーエージェント",
    "At least one event must be selected" : "少なくともイベントを一つ指定してください",
    "Add new flow" : "新しいフローを追加",
    "When" : "いつ",
    "and" : "かつ",
    "Cancel" : "キャンセル",
    "Delete" : "削除",
    "The configuration is invalid" : "設定が正しくありません",
    "Active" : "アクティブ化",
    "Save" : "保存",
    "Available flows" : "利用可能なフロー",
    "For details on how to write your own flow, check out the development documentation." : "独自のフローを作成する方法の詳細については、開発ドキュメントを参照してください。",
    "More flows" : "その他のフロー",
    "Browse the app store" : "アプリストアをブラウザでみる",
    "Show less" : "表示を減らす",
    "Show more" : "表示を増やす",
    "Configured flows" : "設定済みフロー",
    "Your flows" : "作成したフロー",
    "matches" : "一致",
    "does not match" : "一致しない",
    "is" : "は",
    "is not" : "は異なる",
    "File name" : "ファイル名",
    "File MIME type" : "ファイルMIMEタイプ",
    "File size (upload)" : "ファイルサイズ（アップロード）",
    "less" : "より小さい",
    "less or equals" : "より小さいか等しい",
    "greater or equals" : "大きいか等しい",
    "greater" : "大きい",
    "Request remote address" : "リクエスト リモートアドレス",
    "matches IPv4" : "次の IPv4アドレスに合致",
    "does not match IPv4" : "次の IPv4アドレスに合致しない",
    "matches IPv6" : "次の IPv6アドレスに合致",
    "does not match IPv6" : "次の IPv6アドレスに合致しない",
    "File system tag" : "ファイルシステムタグ",
    "is tagged with" : "に次のタグが付いている",
    "is not tagged with" : "に次のタグが付いていない",
    "Request URL" : "呼びだしたURL",
    "Request time" : "ルール適用の時刻",
    "between" : "間",
    "not between" : "間ではない",
    "Request user agent" : "リクエスト時のユーザーエージェント",
    "User group membership" : "ユーザーがグループのメンバーかどうか",
    "is member of" : "が次のグループのメンバーである",
    "is not member of" : "が次のグループのメンバーではない"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.8.tgz: nextcloud/apps/workflowengine/l10n/ja.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定された演算子は無効",
    "The given regular expression is invalid" : "指定の正規表現は無効",
    "The given file size is invalid" : "指定されたファイルサイズは無効",
    "The given tag id is invalid" : "指定されたIDタグは無効",
    "The given IP range is invalid" : "指定されたIP範囲は無効",
    "The given IP range is not valid for IPv4" : "指定されたIPはIPv4の範囲ではありません",
    "The given IP range is not valid for IPv6" : "指定されたIPはIPv6の範囲ではありません",
    "The given time span is invalid" : "指定された期間は無効です",
    "The given start time is invalid" : "指定された開始時刻は無効です",
    "The given end time is invalid" : "指定された終了時刻は無効です",
    "The given group does not exist" : "指定されたグループは存在しません",
    "File" : "ファイル",
    "File created" : "ファイル作成時",
    "File updated" : "ファイル更新時",
    "File renamed" : "ファイル名変更時",
    "File deleted" : "ファイル削除時",
    "File accessed" : "ファイルアクセス時",
    "File copied" : "ファイル複製時",
    "Tag assigned" : "タグ割り当て時",
    "Someone" : "誰か",
    "%s created %s" : "%s が %s を作成",
    "%s modified %s" : "%s が %s を更新",
    "%s deleted %s" : "%s が %s を削除",
    "%s accessed %s" : "%s が %s にアクセス",
    "%s renamed %s" : "%s が %s をリネーム",
    "%s copied %s" : "%s を %s に複製",
    "%s assigned %s to %s" : "%s が %s を %s に割り当て",
    "Operation #%s does not exist" : "#%s 操作は存在しません",
    "Entity %s does not exist" : "エンティティー %s がありません",
    "Entity %s is invalid" : "エンティティー %s が間違っています",
    "No events are chosen." : "イベントが選択されていません。",
    "Entity %s has no event %s" : "エンティティー %s には %s のイベントはありません",
    "Operation %s does not exist" : "%s 操作は存在しません",
    "Operation %s is invalid" : "%s 操作は無効です",
    "At least one check needs to be provided" : "少なくともチェックを一つ設定してください",
    "The provided operation data is too long" : "提供された操作データが長すぎます",
    "Invalid check provided" : "チェック設定が正しくありません",
    "Check %s does not exist" : "チェック %s は存在しません",
    "Check %s is invalid" : "チェック %s は無効です",
    "Check %s is not allowed with this entity" : " チェック%s はこのエンティティーでは利用できません",
    "The provided check value is too long" : "提供されたチェック値が長すぎます",
    "Check #%s does not exist" : "チェック #%s は存在しません",
    "Check %s is invalid or does not exist" : "%sのチェックは無効か存在しません",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Nextcloud ワークフローエンジン",
    "Select a filter" : "フィルターを選択",
    "Select a comparator" : "比較演算子を指定",
    "Select a file type" : "ファイルタイプを指定",
    "e.g. httpd/unix-directory" : "例: httpd/unix-directory",
    "Folder" : "フォルダー",
    "Images" : "画像",
    "Office documents" : "Officeドキュメント",
    "PDF documents" : "PDFドキュメント",
    "Custom mimetype" : "カスタムMIMEタイプ",
    "Select a tag" : "タグを選択",
    "No results" : "該当なし",
    "%s (invisible)" : "%s (不可視)",
    "%s (restricted)" : "%s (制限)",
    "Please enter a valid time span" : "正しい間隔を指定してください",
    "Select a request URL" : "リクエストURLを選択",
    "Predefined URLs" : "定義済みのURL",
    "Files WebDAV" : "ファイルWebDAV",
    "Others" : "その他",
    "Custom URL" : "カスタムURL",
    "Select a user agent" : "ユーザーエージェントを選択",
    "Android client" : "アンドロイドクライアント",
    "iOS client" : "iOSクライアント",
    "Desktop client" : "デスクトップクライアント",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook アドオン",
    "Custom user agent" : "カスタムユーザーエージェント",
    "At least one event must be selected" : "少なくともイベントを一つ指定してください",
    "Add new flow" : "新しいフローを追加",
    "When" : "いつ",
    "and" : "かつ",
    "Cancel" : "キャンセル",
    "Delete" : "削除",
    "The configuration is invalid" : "設定が正しくありません",
    "Active" : "アクティブ化",
    "Save" : "保存",
    "Available flows" : "利用可能なフロー",
    "For details on how to write your own flow, check out the development documentation." : "独自のフローを作成する方法の詳細については、開発ドキュメントを参照してください。",
    "More flows" : "その他のフロー",
    "Browse the App Store" : "AppStoreをブラウザーでみる",
    "Show less" : "表示を減らす",
    "Show more" : "表示を増やす",
    "Configured flows" : "設定済みフロー",
    "Your flows" : "作成したフロー",
    "matches" : "一致",
    "does not match" : "一致しない",
    "is" : "は",
    "is not" : "は異なる",
    "File name" : "ファイル名",
    "File MIME type" : "ファイルMIMEタイプ",
    "File size (upload)" : "ファイルサイズ（アップロード）",
    "less" : "より小さい",
    "less or equals" : "より小さいか等しい",
    "greater or equals" : "大きいか等しい",
    "greater" : "大きい",
    "Request remote address" : "リクエスト リモートアドレス",
    "matches IPv4" : "次の IPv4アドレスに合致",
    "does not match IPv4" : "次の IPv4アドレスに合致しない",
    "matches IPv6" : "次の IPv6アドレスに合致",
    "does not match IPv6" : "次の IPv6アドレスに合致しない",
    "File system tag" : "ファイルシステムタグ",
    "is tagged with" : "に次のタグが付いている",
    "is not tagged with" : "に次のタグが付いていない",
    "Request URL" : "呼びだしたURL",
    "Request time" : "ルール適用の時刻",
    "between" : "間",
    "not between" : "間ではない",
    "Request user agent" : "リクエスト時のユーザーエージェント",
    "User group membership" : "ユーザーがグループのメンバーかどうか",
    "is member of" : "が次のグループのメンバーである",
    "is not member of" : "が次のグループのメンバーではない",
    "Browse the app store" : "アプリストアをブラウザーでみる"
},
"nplurals=1; plural=0;");
